list/fold_right.hpp

The list/fold_right.hpp header defines folding (or accumulating) a list right-to-left.

#### Usage

#include <boost/preprocessor/list/fold_right.hpp>

#### Contents

- BOOST_PP_LIST_FOLD_RIGHT
- BOOST_PP_LIST_FOLD_RIGHT_2ND
- BOOST_PP_LIST_FOLD_RIGHT_2ND_D
- BOOST_PP_LIST_FOLD_RIGHT_d
- BOOST_PP_LIST_FOLD_RIGHT_D

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)